package Task::Mock::Person;

# Pragmas.
use strict;
use warnings;

# Version.
our $VERSION = 0.02;

1;

__END__

=pod

=encoding utf8

=head1 NAME

Task::Mock::Person - Install the Mock::Person modules.

=head1 SYNOPSIS

 cpanm Task::Mock::Person

=head1 SEE ALSO

L<Mock::Person>,
L<Mock::Person::CZ>,
L<Mock::Person::DE>,
L<Mock::Person::EN>,
L<Mock::Person::JP::Person>,
L<Mock::Person::SK>,
L<Mock::Person::SK::ROM>,
L<Mock::Person::SV>.

=head1 REPOSITORY

L<https://github.com/tupinek/Task-Mock-Person>

=head1 AUTHOR

Michal Špaček L<mailto:skim@cpan.org>

L<http://skim.cz>

=head1 LICENSE AND COPYRIGHT

 © 2015 Michal Špaček
 Artistic License
 BSD 2-Clause License

=head1 VERSION

0.02

=cut
